#!/usr/bin/Rscript
## !/biosw/R/3.3.1/bin/Rscript

# RNA modification level estimation with pulseR
# Copyright under the MIT License

# Usage: ./run-prepare-data.R [config]

# load data and save serialised R objects

library(openxlsx)
library(here)
library(stringr)
library(purrr)

# extract replicates from summary SRA Experiments
summary <- read.csv(file=here("mapping/sra_result.csv"), 
    row.names=1)[c('Sample.Accession', 'Experiment.Title')]
summary$rep <- apply(summary['Experiment.Title'], 1, 
    function(string) substring(string, regexpr("rep", string)+3, regexpr("rep", string)+3))

# get sample metadata and reformat, add replicate number
samples <- read.table(here("mapping/run_laic.txt"), 
    sep="\t", header=T)[c('Run', 'SRA_Sample', 'cell_line', 'treatment')]

samples$fraction <- 'total'
samples$fraction[grep("positive", samples$treatment)] <- 'eluate'
samples$fraction[grep("negative", samples$treatment)] <- 'supernatent'

samples <- merge(samples, summary, 
    by.x='SRA_Sample', by.y='Sample.Accession')[c('fraction', 'Run', 'cell_line', 'rep')]
colnames(samples)[colnames(samples)=='cell_line'] <- 'cell'

samples$sample <- apply(samples, 1, 
    function(string) paste(substring(string[3],1,1), string[4], substring(string[1],1,3), sep=''))

# get counts and rename samples
counts <- read.csv(file=here("mapping/gene_count_matrix.csv"), row.names=1)
names(counts) <- sapply(strsplit(names(counts),"_"), `[`, 1)
for (row in 1:nrow(samples)) {
   names(counts)[names(counts)==samples[row, 'Run']] <- samples[row, 'sample']
}

# remove spike-ins
# do not use NanoLuc_533_nts, Venus_734_nts, RenillaLuc_589_nts, GST_704_nts
raw_counts <- subset(counts, !(rownames(counts) %in% grep(rownames(counts), 
    pattern="^ENS", invert=TRUE, value=TRUE)))
spikes <- subset(counts, rownames(counts) %in% grep(rownames(counts), 
    pattern="^ERCC", value=TRUE))
    
# separate cells
gm <- raw_counts[,as.vector(samples$sample[samples$cell == 'GM12878'])]
hs <- raw_counts[,as.vector(samples$sample[samples$cell == 'H1-ESC'])]

# write to disk
dirloc <- here("data")
dir.create(dirloc, recursive=TRUE, showWarnings=FALSE)
saveRDS(samples, file.path(dirloc, "samples.rds"))
# saveRDS(raw_counts, file.path(dirloc, "counts.rds"))
saveRDS(gm, file.path(dirloc, "counts-GM12878.rds"))
saveRDS(hs, file.path(dirloc, "counts-H1-ESC.rds"))
saveRDS(spikes, file.path(dirloc, "counts-ERCC.rds"))

